@@ -2,6 +2,8 @@ use strict;
 use warnings;
 package App::Cmd::Tester;
 
+our $VERSION = 0.306;
+
 =head1 NAME
 
 App::Cmd::Tester - for capturing the result of running an app
@@ -74,6 +76,8 @@ BEGIN {
   };
 }
 
+sub result_class { 'App::Cmd::Tester::Result' }
+
 sub test_app {
   my ($class, $app, $argv) = @_;
 
@@ -85,6 +89,8 @@ sub test_app {
 
   my $run_rv;
 
+  $app = $app->new unless ref($app) or $app->isa('App::Cmd::Simple');
+
   my $ok = eval {
     local $TEST_IN_PROGRESS = 1;
     local @ARGV = @$argv;
@@ -100,19 +106,26 @@ sub test_app {
     $exit_code = $$error;
   }
 
-  bless {
+  $class->result_class->new({
+    app    => $app,
     stdout => $hub->slot_contents('stdout'),
     stderr => $hub->slot_contents('stderr'),
     output => $hub->combined_contents,
     error  => $error,
     run_rv => $run_rv,
     exit_code => $exit_code
-  } => 'App::Cmd::Tester::Result';
+  });
 }
 
 {
   package App::Cmd::Tester::Result;
-  for my $attr (qw(stdout stderr output error run_rv exit_code)) {
+
+  sub new {
+    my ($class, $arg) = @_;
+    bless $arg => $class;
+  }
+
+  for my $attr (qw(app stdout stderr output error run_rv exit_code)) {
     Sub::Install::install_sub({
       code => sub { $_[0]->{$attr} },
       as   => $attr,
